==> dev-bundle-1.21.4-R0.1-20250327.133756-218.zip: patches/io/papermc/paper/entity/activation/ActivationType.java <==
package io.papermc.paper.entity.activation;

import net.minecraft.world.entity.Entity;
import net.minecraft.world.entity.FlyingMob;
import net.minecraft.world.entity.PathfinderMob;
import net.minecraft.world.entity.ambient.AmbientCreature;
import net.minecraft.world.entity.animal.AgeableWaterCreature;
import net.minecraft.world.entity.animal.WaterAnimal;
import net.minecraft.world.entity.monster.Enemy;
import net.minecraft.world.entity.npc.Villager;
import net.minecraft.world.entity.raid.Raider;
import net.minecraft.world.phys.AABB;

public enum ActivationType {
    WATER,
    FLYING_MONSTER,
    VILLAGER,
    MONSTER,
    ANIMAL,
    RAIDER,
    MISC;

    AABB boundingBox = new AABB(0, 0, 0, 0, 0, 0);

    /**
     * Returns the activation type for the given entity.
     *
     * @param entity entity to get the activation type for
     * @return activation type
     */
    public static ActivationType activationTypeFor(final Entity entity) {
        if (entity instanceof WaterAnimal || entity instanceof AgeableWaterCreature) {
            return ActivationType.WATER;
        } else if (entity instanceof Villager) {
            return ActivationType.VILLAGER;
        } else if (entity instanceof FlyingMob && entity instanceof Enemy) {
            return ActivationType.FLYING_MONSTER;
        } else if (entity instanceof Raider) {
            return ActivationType.RAIDER;
        } else if (entity instanceof Enemy) {
            return ActivationType.MONSTER;
        } else if (entity instanceof PathfinderMob || entity instanceof AmbientCreature) {
            return ActivationType.ANIMAL;
        } else {
            return ActivationType.MISC;
        }
    }
}

==> dev-bundle-1.21.5-R0.1-20250613.213059-11.zip: patches/io/papermc/paper/entity/activation/ActivationType.java <==
package io.papermc.paper.entity.activation;

import net.minecraft.world.entity.Entity;
import net.minecraft.world.entity.FlyingMob;
import net.minecraft.world.entity.PathfinderMob;
import net.minecraft.world.entity.ambient.AmbientCreature;
import net.minecraft.world.entity.animal.AgeableWaterCreature;
import net.minecraft.world.entity.animal.WaterAnimal;
import net.minecraft.world.entity.monster.Enemy;
import net.minecraft.world.entity.npc.Villager;
import net.minecraft.world.entity.raid.Raider;
import net.minecraft.world.phys.AABB;

public enum ActivationType {
    WATER,
    FLYING_MONSTER,
    VILLAGER,
    MONSTER,
    ANIMAL,
    RAIDER,
    MISC;

    //AABB boundingBox = new AABB(0, 0, 0, 0, 0, 0); // Folia - threaded regions - replaced by local variable

    /**
     * Returns the activation type for the given entity.
     *
     * @param entity entity to get the activation type for
     * @return activation type
     */
    public static ActivationType activationTypeFor(final Entity entity) {
        if (entity instanceof WaterAnimal || entity instanceof AgeableWaterCreature) {
            return ActivationType.WATER;
        } else if (entity instanceof Villager) {
            return ActivationType.VILLAGER;
        } else if (entity instanceof FlyingMob && entity instanceof Enemy) {
            return ActivationType.FLYING_MONSTER;
        } else if (entity instanceof Raider) {
            return ActivationType.RAIDER;
        } else if (entity instanceof Enemy) {
            return ActivationType.MONSTER;
        } else if (entity instanceof PathfinderMob || entity instanceof AmbientCreature) {
            return ActivationType.ANIMAL;
        } else {
            return ActivationType.MISC;
        }
    }
}
